@@ -65,6 +65,15 @@ class Stenciller using Moose with Stenciller::Utils {
         documentation => 'If a stencil has no output content, skip entire stencil.',
     );
 
+    around BUILDARGS($next: $class, @args) {
+        if(scalar @args == 1 && ref $args[0] eq 'HASH') {
+            $class->$next(%{ $args[0] });
+        }
+        else {
+            $class->$next(@args);
+        }
+    }
+
     method BUILD {
         $self->parse;
     }
@@ -73,9 +82,10 @@ class Stenciller using Moose with Stenciller::Utils {
         return !!$count || 0;
     }
 
-    method transform(Str $plugin_name         does doc('Plugin to read contents with.'),
-                         @constructor_args    does doc('Constructor arguments for the plugin.')
-                 --> Str                      does doc('Returns the transformed contents.')
+    method transform(Str :$plugin_name           does doc('Plugin to read contents with.'),
+                     HashRef :$constructor_args? does doc('Constructor arguments for the plugin.')     = {},
+                     HashRef :$transform_args?   does doc('Settings for the specific transformation.') = {}, ...
+                 --> Str     but assumed         does doc('Returns the transformed content.')
     ) {
 
         my $plugin_class = "Stenciller::Plugin::$plugin_name";
@@ -84,7 +94,7 @@ class Stenciller using Moose with Stenciller::Utils {
         if(!$plugin_class->does('Stenciller::Transformer')) {
             croak("[$plugin_name] doesn't do the Stenciller::Transformer role. Quitting.");
         }
-        return $plugin_class->new(stenciller => $self, @constructor_args)->transform;
+        return $plugin_class->new(stenciller => $self, %{ $constructor_args })->transform($transform_args);
     }
 
     method parse {
@@ -108,7 +118,11 @@ class Stenciller using Moose with Stenciller::Utils {
             if(any { $environment eq $_ } (qw/header next_stencil/)) {
                 $self->add_header_line($line) and next LINE if $line !~ $stencil_start;
 
-                my $settings = $1 ? $self->eval_to_hashref($1, $self->filepath) : {};
+                my $possible_hash = $1;
+                my $settings = defined $possible_hash && $possible_hash =~ m{\{.*\}}
+                             ? $self->eval_to_hashref($possible_hash, $self->filepath)
+                             : {}
+                             ;
 
                 $stencil = Stenciller::Stencil->new(
                             name => exists $settings->{'name'} ? delete $settings->{'name'} : $self->filepath->basename . "-$line_count",
@@ -142,6 +156,9 @@ class Stenciller using Moose with Stenciller::Utils {
                 redo LINE;
             }
         }
+        if($environment ne 'after_output') {
+            croak (sprintf 'File <%s> appears malformed. Ended on <%s>', $self->filepath, $environment);
+        }
         $self->handle_completed_stencil($stencil);
     }
 
@@ -161,7 +178,6 @@ class Stenciller using Moose with Stenciller::Utils {
             $self->add_stencil($clone);
         }
     }
-
 }
 
 __END__
@@ -176,7 +192,7 @@ Stenciller - Transforms textfiles to different output
 
 =head1 VERSION
 
-Version 0.1100, released 2015-01-16.
+Version 0.1200, released 2015-01-17.
 
 =head1 SYNOPSIS
 
@@ -308,6 +324,63 @@ there is a header before the first stencil.
 
 =head1 METHODS
 
+
+=head2 transform
+
+=begin HTML
+
+<p></p>
+
+<table style="margin-bottom: 10px; margin-left: 10px; border-collapse: bollapse;" cellpadding="0" cellspacing="0">
+<tr style="vertical-align: top;"><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8eee8;">Named parameters</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td></tr>
+<tr style="vertical-align: top;">
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>constructor_args =&gt; $value</code>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#HashRef">HashRef</a>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">optional, default <code>= HASH(0xa8778a8)</code>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
+<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Constructor arguments for the plugin.</td>
+</tr>
+<tr style="vertical-align: top;">
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>plugin_name =&gt; $value</code>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">optional, <span style="color: #999;">no default</span></td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
+<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Plugin to read contents with.</td>
+</tr>
+<tr style="vertical-align: top;">
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>transform_args =&gt; $value</code>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#HashRef">HashRef</a>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">optional, default <code>= HASH(0xaf41460)</code>
+
+</td>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
+<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Settings for the specific transformation.</td>
+</tr>
+<tr style="vertical-align: top;"><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">Returns</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td></tr>
+<tr style="vertical-align: top;">
+<td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
+
+</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td>
+<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Returns the transformed content.</td>
+</tr>
+</table>
+
+=end HTML
+
 =head1 PLUGINS
 
 The actual transforming is done by plugins. There are two plugins bundled in this distribution:
