@@ -18,7 +18,7 @@ package Stenciller::Standard {
         my %opts = @_;
 
         push @{ $opts{'imports'} ||= [] } => (
-            'List::AllUtils'    => [qw/any none sum uniq/],
+            'List::AllUtils'    => [qw/any none sum uniq first_index/],
             'feature'           => [qw/:5.14/],
             'Types::Stenciller' => [{ replace => 1 }, '-types'],
             'Path::Tiny'        => ['path'],
@@ -45,7 +45,7 @@ Stenciller::Standard - Import to all
 
 =head1 VERSION
 
-Version 0.1100, released 2015-01-16.
+Version 0.1200, released 2015-01-17.
 
 =head1 SOURCE
 
